cauchy_fit: Fit Cauchy Distribution to a vector of returns/stock prices.
Description
This function fits the Cauchy distribution to a given data vector using the fitdist function
from the fitdistrplus package. It returns the estimated parameters along with the AIC and BIC
values for the fitted distribution.
Usage
cauchy_fit(vec)
Value
a list containing the following elements:
par
a numeric vector of length 2 containing the estimated values for the parameters of the
fitted distribution: lambda (location) and alpha (scale).
aic
the Akaike information criterion (AIC) value for the fitted distribution.
bic
the Bayesian information criterion (BIC) value for the fitted distribution.
Arguments
vec
a numeric vector containing the data to be fitted.