nig_fit: Fit Normal Inverse Gaussian (NIG) Distribution to a vector of returns/stock prices.
Description
This function fits the Normal Inverse Gaussian (NIG) Distribution to a given data vector using the nig_fit function from
the fBasics package. It returns the estimated parameters along with the AIC and BIC values for the fitted
distribution.
Usage
nig_fit(vec)
Value
A list with the following elements:
params
The estimated parameters of the NIG distribution: location, scale, skewness, and shape.
aic
The Akaike Information Criterion (AIC) for the NIG distribution fit.
bic
The Bayesian Information Criterion (BIC) for the NIG distribution fit.