sym.hd_fit: Fit a Symmetric Hyperbolic Distribution to a vector of return/stock prices.
Description
This function fits a Symmetric Hyperbolic distribution to a data vector using the
fit.hypuv function from the ghyp package. It returns the estimated parameters along with
the AIC and BIC values for the fitted distribution.
Usage
sym.hd_fit(vec)
Value
a list containing the following elements:
par
a numeric vector of length 4 containing the estimated values for the parameters of the
fitted distribution: alpha (scale), mu (degrees of freedom), sigma (standard deviation), and gamma (skewness).
aic
the Akaike information criterion (AIC) value for the fitted distribution.
bic
the Bayesian information criterion (BIC) value for the fitted distribution.
Arguments
vec
a numeric vector containing the symmetric data to be fitted.